summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/timespinbox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kalarm/lib/timespinbox.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/timespinbox.h')
-rw-r--r--kalarm/lib/timespinbox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/timespinbox.h b/kalarm/lib/timespinbox.h
index 4bacd4947..0be232453 100644
--- a/kalarm/lib/timespinbox.h
+++ b/kalarm/lib/timespinbox.h
@@ -50,17 +50,17 @@ class TimeSpinBox : public SpinBox2
/** Constructor for a wrapping time spin box which can be used to enter a time of day.
* @param use24hour True for entry of 24-hour clock times (range 00:00 to 23:59).
* False for entry of 12-hour clock times (range 12:00 to 11:59).
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit TimeSpinBox(bool use24hour, TQWidget* tqparent = 0, const char* name = 0);
+ explicit TimeSpinBox(bool use24hour, TQWidget* parent = 0, const char* name = 0);
/** Constructor for a non-wrapping time spin box which can be used to enter a length of time.
* @param minMinute The minimum value which the spin box can hold, in minutes.
* @param maxMinute The maximum value which the spin box can hold, in minutes.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- TimeSpinBox(int minMinute, int maxMinute, TQWidget* tqparent = 0, const char* name = 0);
+ TimeSpinBox(int minMinute, int maxMinute, TQWidget* parent = 0, const char* name = 0);
/** Returns true if the spin box holds a valid value.
* An invalid value is displayed as asterisks.
*/
@@ -50,17 +50,17 @@ class TimeSpinBox : public SpinBox2
* @param use24hour True for entry of 24-hour clock times (range 00:00 to 23:59).
* False for entry of 12-hour clock times (range 12:00 to 11:59).
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -50,17 +50,17 @@ class TimeSpinBox : public SpinBox2
* @param minMinute The minimum value which the spin box can hold, in minutes.
* @param maxMinute The maximum value which the spin box can hold, in minutes.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/